@@ -5,7 +5,7 @@ import redis
 from copy import deepcopy
 from typing import Callable
 from django.db.models import Model as DjangoModel
-import django.db.models.fields as django_fields
+from django.db import models as django_fields
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
 
@@ -489,7 +489,7 @@ class RedisRoot:
             def create_redis_model_from_django_model(django_model, redis_root):
                 redis_fields = {}
                 for django_field in django_model._meta.get_fields():
-                    redis_field = self.django_field_to_redis_field(django_model, django_field)
+                    redis_field = django_field_to_redis_field(django_model, django_field)
                     django_field_name = django_field.name
                     if django_field_name in ['id', 'pk']:
                         django_field_name = 'django_id'
